This crate contains kube-rs compatible bindings for Kubernetes custom resources for the leaksignal.com group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
leaksignal.com/v1
ClusterLeaksignalIstioLeaksignalIstio